km3pipe\.dataclasses\.KM3Array
==============================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: KM3Array

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~KM3Array.__init__
      ~KM3Array.all
      ~KM3Array.any
      ~KM3Array.argmax
      ~KM3Array.argmin
      ~KM3Array.argpartition
      ~KM3Array.argsort
      ~KM3Array.astype
      ~KM3Array.byteswap
      ~KM3Array.choose
      ~KM3Array.clip
      ~KM3Array.compress
      ~KM3Array.conj
      ~KM3Array.conjugate
      ~KM3Array.conv_from
      ~KM3Array.conv_to
      ~KM3Array.copy
      ~KM3Array.cumprod
      ~KM3Array.cumsum
      ~KM3Array.deserialise
      ~KM3Array.diagonal
      ~KM3Array.dot
      ~KM3Array.dump
      ~KM3Array.dumps
      ~KM3Array.fill
      ~KM3Array.flatten
      ~KM3Array.from_dict
      ~KM3Array.getfield
      ~KM3Array.item
      ~KM3Array.itemset
      ~KM3Array.max
      ~KM3Array.mean
      ~KM3Array.min
      ~KM3Array.newbyteorder
      ~KM3Array.nonzero
      ~KM3Array.partition
      ~KM3Array.prod
      ~KM3Array.ptp
      ~KM3Array.put
      ~KM3Array.ravel
      ~KM3Array.repeat
      ~KM3Array.reshape
      ~KM3Array.resize
      ~KM3Array.round
      ~KM3Array.searchsorted
      ~KM3Array.serialise
      ~KM3Array.setfield
      ~KM3Array.setflags
      ~KM3Array.sort
      ~KM3Array.squeeze
      ~KM3Array.std
      ~KM3Array.sum
      ~KM3Array.swapaxes
      ~KM3Array.take
      ~KM3Array.tobytes
      ~KM3Array.tofile
      ~KM3Array.tolist
      ~KM3Array.tostring
      ~KM3Array.trace
      ~KM3Array.transpose
      ~KM3Array.var
      ~KM3Array.view
   
   

   
   
   